@@ -25,6 +25,7 @@ class SAGAHadoopCLI(object):
                           working_directory=os.getcwd(),
                           number_cores=1,
                           cores_per_node=1,
+			  spmd_variation=None
                      ):
         
         try:
@@ -44,6 +45,8 @@ class SAGAHadoopCLI(object):
             jd.output =  os.path.join("hadoop_job.stdout")
             jd.error  = os.path.join("hadoop_job.stderr")
             jd.working_directory=working_directory
+            if spmd_variation!=None:
+                jd.spmd_variation=spmd_variation
             # create the job (state: New)
             myjob = js.create_job(jd)
     
@@ -77,13 +80,16 @@ class SAGAHadoopCLI(object):
             pass
         hadoop_home=os.path.join(os.getcwd(), "work/hadoop-2.2.0")
         print "HADOOP installation directory: %s"%hadoop_home
-        print "Allocated Resources for Hadoop cluster: " + hosts 
-        print "YARN Web Interface: http://%s:8088"% hosts[:hosts.find("/")]
-        print "HDFS Web Interface: http://%s:50070"% hosts[:hosts.find("/")]   
+        #print "Allocated Resources for Hadoop cluster: " + hosts 
+        #print "YARN Web Interface: http://%s:8088"% hosts[:hosts.find("/")]
+        #print "HDFS Web Interface: http://%s:50070"% hosts[:hosts.find("/")]   
         print "(please allow some time until the Hadoop cluster is completely initialized)"
         print "\nTo use Hadoop set HADOOP_CONF_DIR: "
         print "export HADOOP_CONF_DIR=%s"%(os.path.join(os.getcwd(), "work", self.get_most_current_job(), "etc/hadoop")) 
-        print "%s/bin/hadoop dfsadmin -report"%hadoop_home
+        print "export HADOOP_HOME=%s"%(hadoop_home) 
+        print "export PATH=%s/bin:$PATH"%(hadoop_home) 
+        print "\nSmoke Test:"
+        print "hadoop dfsadmin -report"
         print ""     
     
     def get_most_current_job(self):
@@ -148,8 +154,12 @@ def main():
                               default="fork://localhost")
     saga_hadoop_group.add_argument('--working_directory', action="store", nargs="?", metavar="WORKING_DIRECTORY", 
                               help="submit a job to specified resource, e.g. fork://localhost",
-                              default=os.getcwd())    
+                              default=None)    
         
+    saga_hadoop_group.add_argument('--spmd_variation', action="store", nargs="?", metavar="SPMD_VARIATION", 
+                              help="Parallel environment, e.g. openmpi",
+                              default=os.getcwd())    
+
     saga_hadoop_group.add_argument('--number_cores', default="1", nargs="?")
     saga_hadoop_group.add_argument('--cores_per_node',  default="1", nargs="?")    
         
@@ -163,10 +173,11 @@ def main():
         app.submit_hadoop_job(resource_url=parsed_arguments.resource, 
                               working_directory=parsed_arguments.working_directory, 
                               number_cores=parsed_arguments.number_cores, 
-                              cores_per_node=parsed_arguments.cores_per_node)
+                              cores_per_node=parsed_arguments.cores_per_node,
+			      spmd_variation=parsed_arguments.spmd_variation)
     
     
         
 if __name__ == '__main__':
     main()
-    
\ No newline at end of file
+    
